@@ -1,13 +1,13 @@
 # LLNG wrapper class to enable CDA handler with auto-protected PSGI
 #
-# See http://lemonldap-ng.org/documentation/latest/handlerarch
-package Lemonldap::NG::Handler::Server::CDA;
+# See https://lemonldap-ng.org/documentation/latest/handlerarch
+package Lemonldap::NG::Handler::PSGI::CDA;
 
 use strict;
 
 use base 'Lemonldap::NG::Handler::Lib::CDA',
   'Lemonldap::NG::Handler::PSGI::Main';
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.2';
 
 1;
